@@ -18,5 +18,9 @@
     --- 靠边窗口功能完成(任意窗口都可以加上该功能),PullOver类 导入方式 from PyQtGuiLib.core.pullOver import PullOver
     --- 靠边窗口功能的测试用例已编写
 2022.12.20  0.0.3.0版本
-    --- 新增圆环功能
+    --- 新增圆环进度条
+2022.12.22  0.0.4.0版本
+    --- 修复了一些小的BUG
+    --- 放弃了亚克力窗口的研究
+    --- 新增加载进度条
 '''
\ No newline at end of file
